==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorPanelDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { PropertyEditorPropertyDescriptionDescriptionModule } from "./PropertyEditorPropertyDescriptionDescriptionModule";
import { PropertyEditorPanelDescriptionMetadata } from "./PropertyEditorPanelDescriptionMetadata";
/**
 * @hidden
 */
var PropertyEditorPanelDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPanelDescriptionModule, _super);
    function PropertyEditorPanelDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPanelDescriptionModule.register = function (a) {
        PropertyEditorPropertyDescriptionDescriptionModule.register(a);
        PropertyEditorPanelDescriptionMetadata.d(a);
    };
    PropertyEditorPanelDescriptionModule.$t = markType(PropertyEditorPanelDescriptionModule, 'PropertyEditorPanelDescriptionModule');
    return PropertyEditorPanelDescriptionModule;
}(Base));
export { PropertyEditorPanelDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/PropertyEditorPanelDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { PropertyEditorPropertyDescriptionDescriptionModule } from "./PropertyEditorPropertyDescriptionDescriptionModule";
import { ToolbarDescriptionModule } from "./ToolbarDescriptionModule";
import { PropertyEditorPanelDescriptionMetadata } from "./PropertyEditorPanelDescriptionMetadata";
/**
 * @hidden
 */
var PropertyEditorPanelDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorPanelDescriptionModule, _super);
    function PropertyEditorPanelDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPanelDescriptionModule.register = function (a) {
        PropertyEditorPropertyDescriptionDescriptionModule.register(a);
        ToolbarDescriptionModule.register(a);
        PropertyEditorPanelDescriptionMetadata.d(a);
    };
    PropertyEditorPanelDescriptionModule.$t = markType(PropertyEditorPanelDescriptionModule, 'PropertyEditorPanelDescriptionModule');
    return PropertyEditorPanelDescriptionModule;
}(Base));
export { PropertyEditorPanelDescriptionModule };
